<?php

/**
 * Simple Product Viewer for Annapol.com
 * @example read file example.php
 */


namespace annapol_products_xml;


class annapol_products_xml {


        /**
         * @var string url address xml file to annapol.com
         */
        public $xml_file = '';

        /**
         * @var string tmp directory
         */
        public $tmp = 'tmp/';


        /**
         * @var string xml file name to save
         */
        public $tmp_filename = 'products.xml';


        public function __construct() {}


        public function filename() {
            return $this->tmp . $this->tmp_filename;
        }


        private function curl() {
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $this->xml_file );
            curl_setopt($ch, CURLOPT_HEADER, 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            ob_start();
            curl_exec($ch);
            curl_close($ch);
            $string = ob_get_contents();

            ob_end_clean();

            return $string;
        }


        public function download() {

            if( !is_dir($this->tmp) ) {
                mkdir($this->tmp);
            }

            if( !is_writable($this->tmp) ) {
                chmod($this->tmp, 777);
            }

            if( !function_exists('curl_init') ) {
                throw new Exception('Sorry, CURL library no exists. Please enable PHP CURL.');
                exit;
            }

            $string = $this->curl();

            $file = fopen( $this->filename(), 'w+');
            fwrite($file, $string);
            fclose($file);

        }


        public function get_products() {

            if( !function_exists('simplexml_load_file') ) {
                throw new Exception('Sorry, SIMPLEXML library no exists. Please enable PHP SIMPLEXML.');
                exit;
            }

            if( !file_exists( $this->filename() ) ) {
                throw new Exception('Sorry, xml file not exists. Please downloaded xml file. Check example.xml or method download.');
                exit;
            }

            $xml = simplexml_load_file( $this->filename(), null, LIBXML_NOCDATA );

            $arr = [];
            foreach( $xml->group->product as $element ) {
                $arr[ (int)$element->attributes()->id ] = [
                    'id' => (int)$element->attributes()->id,
                    'symbol' => (string)$element->attributes()->symbol,
                    'status' => (int)$element->on_request->attributes()->status,
                    'price' => [
                        'pln' => (double)$element->attributes()->price_pln,
                        'eur' => (double)$element->attributes()->price_eur
                    ],
                    'tax' => (double)$element->attributes()->tax,
                    'stock' => (double)$element->attributes()->stock,
                    'name' => (string)$element->name,
                    'manufacturers' => (string)$element->manufacturers_name,
                    'category' => [
                        'id' => (int)$element->category->id,
                        'name' => (string)$element->category->name
                    ],
                    'description' => (string)$element->description,
                    'images' => (array)$element->images->gfx
                ];
            }

            return $arr;

        }


    }

?>
